poster.pdf: poster.tex iota-logo.jpg atom_chips.png cnes.jpg CNRS.pdf background_desaturate.jpg schematic.jpg text.pdf 1D_atom_cloud_1jet.jpg 2D_MOT_chamber.jpg 2D_MOT_schematics.png suspended_chamber.jpg whole_setup1.jpg laser_sign.pdf recirculation_mp.pdf compressible_mp.pdf light_shifts_gplot.tex light_shifts_gplot.pdf optical_trap_gplot.tex optical_trap_gplot.pdf compressible_gplot.tex compressible_gplot.pdf 

	 pdflatex poster.tex

all:	pdf

dvi:	${TeXfile}.dvi

ps:	${TeXfile}.ps

pdf:	${TeXfile}.pdf

bbl:	${TeXfile}.bbl
	latex ${TeXfile}
	latex ${TeXfile}

clean:
	rm -f ${TeXfile}.{aux,log,blg,bbl,toc,snm,out,nav,dvi}
	rm -f *.make
	rm -f *_gplot.tex.{aux,log,eps,tex}
	rm -f ${TeXfile}_trans.*
	rm -f *.mpo *.mpx *-1.pdf *-1.ps *.log *_mp.eps *_mp.pdf
	rm -f tmpgraph.{bck,log,tmp,tui}

${TeXfile}.pdf: ${TeXfile}.pdf.make
	@make --no-print-directory -f ${TeXfile}.pdf.make ${TeXfile}.pdf

${TeXfile}.bbl:	${TeXfile}.aux
	bibtex ${TeXfile}

${TeXfile}.dvi: ${TeXfile}.dvi.make
	@make --no-print-directory -f ${TeXfile}.dvi.make ${TeXfile}.dvi

###############
# dependance files
${TeXfile}.pdf.make:
	@echo Generating dependancies for ${TeXfile}.pdf
	@./texdep ${TeXfile}.pdf > $@
	@printf "\n\t pdflatex ${TeXfile}.tex\n" >> $@
# tell make I want the autogenerated Makefile to be rebuilt
.PHONY: ${TeXfile}.pdf.make
# dependance files
${TeXfile}.dvi.make:
	@echo Generating dependancies for ${TeXfile}.dvi
	@./texdep ${TeXfile}.dvi > $@
	@printf "\n\t latex ${TeXfile}.tex\n" >> $@
# tell make I want the autogenerated Makefile to be rebuilt
.PHONY: ${TeXfile}.dvi.make


###############
# Metapost generated postscripts or pdfs :
%_mp.eps: %-1.pdf
	pdftops -eps $< $@
%_mp.pdf: %-1.pdf
	cp $< $@
%-1.pdf: %.mp
	mptopdf $< $@
	rm -f tmpgraph.{bck,log,tmp,tui}
	rm -f mpgraph.mp mprun.mp mptrace.tmp 
	rm ${basename $<}.1

###############
# Implicite rules :
# eps from sketch files
%.eps: %.sk
	sk2ps $< $@
# eps files from xfig files
%.eps: %.fig
	fig2dev -L ps $< $@
# pdf files from TeX files
#%.pdf: %.tex
#	pdflatex $<
# pdf files from eps files
%.pdf: %.eps
	epstopdf $<
# dvi files from TeX files
%.dvi: %.tex
	latex $<
# ps files from dvi files
%.ps: %.dvi
	dvips $< -o $@
# tex files generated by gnuplot
%_gplot.tex: %.gplot
	gnuplot $<

